# coding: utf-8
require "spec_helper"

describe FastshopCatalog::OrderPlacementService do

  include Savon::SpecHelper
  before(:all) { savon.mock! }
  after(:all)  { savon.unmock! }

  let(:contract_number) do
    "1234567890"
  end
  
  let(:order) do
    order = FastshopCatalog::Entity::Order.new
    order.contract_code = '1234567890'
    order.zip_code = '02029001'
    order.document = '73978898160'
    order.number = '1560'
    order.total_amount = "69.00"
    order.delivery_type = "P"
    order.partner_order_number = "1234568119"
    order_item = FastshopCatalog::Entity::OrderItem.new
    order_item.sku = 'IVIEP314RED'
    order_item.quantity = 1
    order_item.price = "69.00"
    order.items = [order_item]
    order
  end

  let(:service) do
    service = FastshopCatalog::OrderPlacementService.new
  end

  let(:order_attr) do
    File.read("spec/fixtures/order_placement_successful_payload.json")
  end

  let(:fixture_address_not_found) do
    File.read("spec/fixtures/order_placement_address_not_found.xml")
  end

  let(:fixture_wrong_contract) do
    File.read("spec/fixtures/catalog_service_wrong_contract_response.xml")
  end

  describe "place_order" do

    it "should raise cart not identified" do
      encrypted_payload = service.encrypt(order_attr)
      savon.expects(:incluir_pedido).with(:message => {'tns:contrato' => contract_number,
        'tns:entrada' => encrypted_payload, 'tns:salt' => ''}).returns(fixture_address_not_found)
      expect{service.place_order(order)}.to raise_error(FastshopCatalog::ServiceException) do |e|
        expect(e.code).to eq(15)
        expect(e.description).to eq('Endereço nao encontrado')
      end
    end

  end

end
